.. python-pointfree documentation master file, created by
   sphinx-quickstart on Mon Nov  7 01:04:16 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pointfree documentation
=======================

:Author: Mark Shroyer
:Email: code@markshroyer.com
:Release: |version|
:Date: |today|

:py:mod:`pointfree` is a module providing Pythonic pointfree-style
programming.  This is its documentation.

.. toctree::
   :maxdepth: 2

   overview
   module
   faq
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

